@@ -6,11 +6,11 @@ import socket
 from dataclasses import dataclass
 from datetime import date, datetime, timedelta, timezone
 from importlib import metadata
-from typing import Any
+from typing import Any, cast
 
-import aiohttp
 import async_timeout
-from aiohttp import hdrs
+from aiohttp.client import ClientError, ClientSession
+from aiohttp.hdrs import METH_GET
 from yarl import URL
 
 from .exceptions import (
@@ -21,22 +21,13 @@ from .exceptions import (
 from .models import Electricity, Gas
 
 
-def get_utcnow() -> datetime:
-    """Get the current UTC time.
-
-    Returns:
-        The current UTC time.
-    """
-    return datetime.now(timezone.utc)
-
-
 @dataclass
 class EnergyZero:
     """Main class for handling data fetching from EnergyZero."""
 
     incl_btw: str = "true"
     request_timeout: float = 10.0
-    session: aiohttp.client.ClientSession | None = None
+    session: ClientSession | None = None
 
     _close_session: bool = False
 
@@ -44,20 +35,23 @@ class EnergyZero:
         self,
         uri: str,
         *,
-        method: str = hdrs.METH_GET,
+        method: str = METH_GET,
         params: dict[str, Any] | None = None,
     ) -> Any:
         """Handle a request to the API of EnergyZero.
 
         Args:
+        ----
             uri: Request URI, without '/', for example, 'status'
             method: HTTP method to use, for example, 'GET'
             params: Extra options to improve or limit the response.
 
         Returns:
+        -------
             A Python dictionary (json) with the response from EnergyZero.
 
         Raises:
+        ------
             EnergyZeroConnectionError: An error occurred while
                 communicating with the API.
             EnergyZeroError: Received an unexpected response from
@@ -65,7 +59,7 @@ class EnergyZero:
         """
         version = metadata.version(__package__)
         url = URL.build(scheme="https", host="api.energyzero.nl", path="/v1/").join(
-            URL(uri)
+            URL(uri),
         )
 
         headers = {
@@ -74,7 +68,7 @@ class EnergyZero:
         }
 
         if self.session is None:
-            self.session = aiohttp.ClientSession()
+            self.session = ClientSession()
             self._close_session = True
 
         try:
@@ -88,64 +82,99 @@ class EnergyZero:
                 )
                 response.raise_for_status()
         except asyncio.TimeoutError as exception:
+            msg = "Timeout occurred while connecting to the API."
             raise EnergyZeroConnectionError(
-                "Timeout occurred while connecting to the API."
+                msg,
             ) from exception
-        except (aiohttp.ClientError, socket.gaierror) as exception:
+        except (ClientError, socket.gaierror) as exception:
+            msg = "Error occurred while communicating with the API."
             raise EnergyZeroConnectionError(
-                "Error occurred while communicating with the API."
+                msg,
             ) from exception
 
         content_type = response.headers.get("Content-Type", "")
         if "application/json" not in content_type:
             text = await response.text()
+            msg = "Unexpected content type response from the EnergyZero API"
             raise EnergyZeroError(
-                "Unexpected content type response from the EnergyZero API",
+                msg,
                 {"Content-Type": content_type, "response": text},
             )
 
-        return await response.json()
+        return cast(dict[str, Any], await response.json())
 
     async def gas_prices(
-        self, start_date: date, end_date: date, interval: int = 4
+        self,
+        start_date: date,
+        end_date: date,
+        interval: int = 4,
     ) -> Gas:
         """Get gas prices for a given period.
 
         Args:
+        ----
             start_date: Start date of the period.
             end_date: End date of the period.
             interval: Interval of the prices.
 
         Returns:
+        -------
             A Python dictionary with the response from EnergyZero.
 
         Raises:
+        ------
             EnergyZeroNoDataError: No gas prices found for this period.
         """
-        start_date_utc: datetime
-        end_date_utc: datetime
-        if get_utcnow().hour >= 5 and get_utcnow().hour <= 22:
-            # Set start_date to 05:00:00 and the end_date to 04:59:59 UTC next day
-            start_date_utc = datetime(
-                start_date.year, start_date.month, start_date.day, 5, 0, 0
-            )
-            end_date_utc = datetime(
-                end_date.year, end_date.month, end_date.day, 4, 59, 59
-            ) + timedelta(days=1)
-        else:
-            # Set start_date to 05:00:00 prev day and the end_date to 04:59:59 UTC
-            start_date_utc = datetime(
-                start_date.year, start_date.month, start_date.day, 5, 0, 0
-            ) - timedelta(days=1)
-            end_date_utc = datetime(
-                end_date.year, end_date.month, end_date.day, 4, 59, 59
-            )
+        local_tz = datetime.now(timezone.utc).astimezone().tzinfo
+        now: datetime = datetime.now(tz=local_tz)
 
+        if now.hour >= 6 and now.hour <= 23:
+            # Set start_date to 06:00:00 and the end_date to 05:59:59 next day
+            # Convert to UTC time 04:00:00 and 03:59:59 next day
+            utc_start_date = datetime(
+                start_date.year,
+                start_date.month,
+                start_date.day,
+                6,
+                0,
+                0,
+                tzinfo=local_tz,
+            ).astimezone(timezone.utc)
+            utc_end_date = datetime(
+                end_date.year,
+                end_date.month,
+                end_date.day,
+                5,
+                59,
+                59,
+                tzinfo=local_tz,
+            ).astimezone(timezone.utc) + timedelta(days=1)
+        else:
+            # Set start_date to 06:00:00 prev day and the end_date to 05:59:59
+            # Convert to UTC time 04:00:00 prev day and 03:59:59 current day
+            utc_start_date = datetime(
+                start_date.year,
+                start_date.month,
+                start_date.day,
+                6,
+                0,
+                0,
+                tzinfo=local_tz,
+            ).astimezone(timezone.utc) - timedelta(days=1)
+            utc_end_date = datetime(
+                end_date.year,
+                end_date.month,
+                end_date.day,
+                5,
+                59,
+                59,
+                tzinfo=local_tz,
+            ).astimezone(timezone.utc)
         data = await self._request(
             "energyprices",
             params={
-                "fromDate": start_date_utc.strftime("%Y-%m-%dT%H:%M:%S.000Z"),
-                "tillDate": end_date_utc.strftime("%Y-%m-%dT%H:%M:%S.999Z"),
+                "fromDate": utc_start_date.strftime("%Y-%m-%dT%H:%M:%S.000Z"),
+                "tillDate": utc_end_date.strftime("%Y-%m-%dT%H:%M:%S.999Z"),
                 "interval": interval,
                 "usageType": 3,
                 "inclBtw": self.incl_btw.lower(),
@@ -153,37 +182,57 @@ class EnergyZero:
         )
 
         if data["Prices"] == []:
-            raise EnergyZeroNoDataError("No gas prices found for this period.")
+            msg = "No gas prices found for this period."
+            raise EnergyZeroNoDataError(msg)
         return Gas.from_dict(data)
 
     async def energy_prices(
-        self, start_date: date, end_date: date, interval: int = 4
+        self,
+        start_date: date,
+        end_date: date,
+        interval: int = 4,
     ) -> Electricity:
         """Get energy prices for a given period.
 
         Args:
+        ----
             start_date: Start date of the period.
             end_date: End date of the period.
             interval: Interval of the prices.
 
         Returns:
+        -------
             A Python dictionary with the response from EnergyZero.
 
         Raises:
+        ------
             EnergyZeroNoDataError: No energy prices found for this period.
         """
-        # Set the start date to 23:00:00 previous day and the end date to 22:59:59 UTC
-        start_date_utc: datetime = datetime(
-            start_date.year, start_date.month, start_date.day, 0, 0, 0
-        ) - timedelta(hours=1)
-        end_date_utc: datetime = datetime(
-            end_date.year, end_date.month, end_date.day, 22, 59, 59
-        )
+        local_tz = datetime.now(timezone.utc).astimezone().tzinfo
+        # Set start_date to 00:00:00 and the end_date to 23:59:59 and convert to UTC
+        utc_start_date = datetime(
+            start_date.year,
+            start_date.month,
+            start_date.day,
+            0,
+            0,
+            0,
+            tzinfo=local_tz,
+        ).astimezone(timezone.utc)
+        utc_end_date = datetime(
+            end_date.year,
+            end_date.month,
+            end_date.day,
+            23,
+            59,
+            59,
+            tzinfo=local_tz,
+        ).astimezone(timezone.utc)
         data = await self._request(
             "energyprices",
             params={
-                "fromDate": start_date_utc.strftime("%Y-%m-%dT%H:%M:%S.000Z"),
-                "tillDate": end_date_utc.strftime("%Y-%m-%dT%H:%M:%S.999Z"),
+                "fromDate": utc_start_date.strftime("%Y-%m-%dT%H:%M:%S.000Z"),
+                "tillDate": utc_end_date.strftime("%Y-%m-%dT%H:%M:%S.999Z"),
                 "interval": interval,
                 "usageType": 1,
                 "inclBtw": self.incl_btw.lower(),
@@ -191,7 +240,8 @@ class EnergyZero:
         )
 
         if data["Prices"] == []:
-            raise EnergyZeroNoDataError("No energy prices found for this period.")
+            msg = "No energy prices found for this period."
+            raise EnergyZeroNoDataError(msg)
         return Electricity.from_dict(data)
 
     async def close(self) -> None:
@@ -202,7 +252,8 @@ class EnergyZero:
     async def __aenter__(self) -> EnergyZero:
         """Async enter.
 
-        Returns:
+        Returns
+        -------
             The EnergyZero object.
         """
         return self
@@ -211,6 +262,7 @@ class EnergyZero:
         """Async exit.
 
         Args:
+        ----
             _exc_info: Exec type.
         """
         await self.close()
